<?php
/* $Id: russian-utf-8.inc.php 10110 2007-03-15 21:11:38Z lem9 $ */

/**
 * Translated by Gosha Sakovich <gt2 at users.sourceforge.net>
 *               Artyom Rabzonov <tyomych at gmx.net>
 *               Nicolay Zakharov <info at melody.org.ru> 16-Dec-2002
 *               (nobody) 2004-09-18
 */

$charset = 'utf-8';
$allow_recoding = TRUE;
$text_dir = 'ltr';
$number_thousands_separator = ',';
$number_decimal_separator = '.';
// shortcuts for Byte, Kilo, Mega, Giga, Tera, Peta, Exa
// по ГОСТ 8.417-2002
$byteUnits = array('Байт', 'КБ', 'МБ', 'ГБ', 'ТБ', 'ПБ', 'ЭБ');

$day_of_week = array('Вс', 'Пн', 'Вт', 'Ср', 'Чт', 'Пт', 'Сб');
$month = array('Янв', 'Фев', 'Мар', 'Апр', 'Май', 'Июн', 'Июл', 'Авг', 'Сен', 'Окт', 'Ноя', 'Дек');
// See http://www.php.net/manual/en/function.strftime.php to define the
// variable below
$datefmt = '%B %d %Y г., %H:%M';
$timespanfmt = '%s дней, %s часов, %s минут и %s секунд';

$strAbortedClients = 'Отменены';
$strAccessDenied = 'В доступе отказано';
$strAccessDeniedCreateConfig = 'Возможная причина - отсутствие файла конфигурации. Для его создания вы можете воспользоваться %1$sсценарием установки%2$s.';
$strAccessDeniedExplanation = 'phpMyAdmin попытался соединиться с сервером MySQL, но сервер отверг соединение. Проверьте имя хоста, пользователя и пароль в config.inc.php.';
$strAction = 'Действие';
$strAddAutoIncrement = 'Добавить значение AUTO_INCREMENT';
$strAddClause = 'Добавить %s';
$strAddConstraints = 'Добавить ограничения';
$strAddDeleteColumn = 'Добавить/удалить столбец критерия';
$strAddDeleteRow = 'Добавить/удалить ряд критерия';
$strAddFields = 'Добавить %s поле(я)';
$strAddHeaderComment = 'Добавить собственный комментарий в заголовок (перевод строки: \\n)';
$strAddIntoComments = 'Добавить в комментарии';
$strAddNewField = 'Добавить новое поле';
$strAddPrivilegesOnDb = 'Добавить привилегии на следующую базу';
$strAddPrivilegesOnTbl = ' Добавить привилегии на следующую таблицу';
$strAddSearchConditions = 'Добавить условия поиска (тело для условия "where"):';
$strAddToIndex = 'Добавить к индексу&nbsp;%s&nbsp;колонку(и)';
$strAddUser = 'Добавить нового пользователя';
$strAddUserMessage = 'Был добавлен новый пользователь.';
$strAdministration = 'Администрирование';
$strAffectedRows = 'Затронутые ряды:';
$strAfter = 'После %s';
$strAfterInsertBack = 'Возврат';
$strAfterInsertNewInsert = 'Вставить новую запись';
$strAfterInsertNext = 'Редактировать следующую строку';
$strAfterInsertSame = 'Возвратиться к этой странице';
$strAll = 'Все';
$strAllTableSameWidth = 'показать все таблицы с такой шириной?';
$strAlterOrderBy = 'Изменить порядок таблицы';
$strAnalyzeTable = 'Анализ таблицы';
$strAnd = 'И';
$strAndThen = 'а затем';
$strAnIndex = 'Был добавлен индекс для %s';
$strAny = 'Любой';
$strAnyHost = 'Любой хост';
$strAnyUser = 'Любой пользователь';
$strApproximateCount = 'Может быть приблизительно. См. FAQ 3.11';
$strAPrimaryKey = 'Был добавлен первичный ключ к %s';
$strArabic = 'Арабский';
$strArmenian = 'Армянский';
$strAscending = 'По возрастанию';
$strAtBeginningOfTable = 'В начало таблицы';
$strAtEndOfTable = 'В конец таблицы';
$strAttr = 'Атрибуты';
$strAutodetect = 'Автодетект';
$strAutomaticLayout = 'Автоматическая раскладка';

$strBack = 'Назад';
$strBaltic = 'Балтийский';
$strBeginCut = 'BEGIN CUT';
$strBeginRaw = 'BEGIN RAW';
$strBinary = ' Двоичный ';
$strBinaryDoNotEdit = ' Двоичные данные - не редактируются ';
$strBinLogEventType = 'Тип события';
$strBinLogInfo = 'Информация';
$strBookmarkAllUsers = 'Дать каждому пользователю использовать эту закладку';
$strBookmarkCreated = 'Закладка %s создана';
$strBookmarkDeleted = 'Закладка была удалена.';
$strBookmarkLabel = 'Метка';
$strBookmarkQuery = 'Закладка на SQL-запрос';
$strBookmarkReplace = 'Заменить существующую закладку с таким именем.';
$strBookmarkThis = 'Закладка на данный SQL-запрос';
$strBookmarkView = 'Только просмотр';
$strBrowse = 'Обзор';
$strBrowseDistinctValues = 'Обзор уникальных значений';
$strBulgarian = 'Болгарский';
$strBzError = 'phpMyAdmin не может сжать дамп из-за проблем с Bz2 extension в текущей версии PHP. Строго рекомендуется установить переменной <code>$cfg[\'BZipDump\']</code> в Вашем конфигурационном файле phpMyAdmin значение <code>FALSE</code>. Если Вы хотите использовать Bz2-компрессию, Вам необходимо обновить PHP. Смотрите PHP bug report %s для более подробной информации.';
$strBzip = 'архивировать в bzip';

$strCalendar = 'Календарь';
$strCannotLogin = 'Невозможно войти в MySQL';
$strCantLoad = 'не могу загрузить расширение %s,<br />проверьте конфигурацию PHP, пожалуйста';
$strCantLoadRecodeIconv = 'Не могу загрузить iconv или recode, необходимые для перекодирования символов. Проверьте php-конфигурацию и разрешите их использование или запретите перекодирование символов в phpMyAdmin.';
$strCantRenameIdxToPrimary = 'Невозможно переименовать индекс в PRIMARY!';
$strCantUseRecodeIconv = 'Не могу использовать iconv функции: ни libiconv, ни recode_string, пока не будут загружены extension reports. Проверьте php-конфигурацию.';
$strCardinality = 'Количество элементов';
$strCaseInsensitive = 'нечувствительный к регистру';
$strCaseSensitive = 'чувствительный к регистру ';
$strCentralEuropean = 'Центрально-Европейский';
$strChange = 'Изменить';
$strChangeCopyMode = 'Создать нового пользователя с такими же привилегиями и ...';
$strChangeCopyModeCopy = '... сохранить старого.';
$strChangeCopyModeDeleteAndReload = ' ... удалить старого из таблиц пользователей и перезагрузить привилегии.';
$strChangeCopyModeJustDelete = ' ... удалить старого из таблиц пользователей.';
$strChangeCopyModeRevoke = ' ... отменить все активные привилегии старого и затем удалить его.';
$strChangeCopyUser = 'Изменить информацию логина/ Копировать пользователя';
$strChangeDisplay = 'Выберите поле для отображения';
$strChangePassword = 'Изменить пароль';
$strCharset = 'Кодировка';
$strCharsetOfFile = 'Кодировка файла:';
$strCharsets = 'Кодировки';
$strCharsetsAndCollations = 'Кодировки и сравнения';
$strCheckAll = 'Отметить все';
$strCheckOverhead = 'Отметить требующие оптимизации';
$strCheckPrivs = 'Проверить привилегии';
$strCheckPrivsLong = 'Проверить привилегии для базы &quot;%s&quot;.';
$strCheckTable = 'Проверить таблицу';
$strChoosePage = 'Выберите страницу для редактирования';
$strColComFeat = 'Показать комментария столбцов';
$strCollation = 'Сравнение';
$strColumnNames = 'Названия колонок';
$strColumnPrivileges = 'Привилегии, специфичные для столбца';
$strCommand = 'Команда';
$strComments = 'Комментарии';
$strCommentsForTable = 'Комментарии к таблице';
$strCompatibleHashing = 'MySQL&nbsp;4.0 совместимо';
$strCompleteInserts = 'Полная вставка';
$strCompression = 'Сжатие';
$strCompressionWillBeDetected = 'Автоматическое определение типа сжатия файла импорта из: %s';
$strConfigDefaultFileError = 'Невозможно загрузить конфигурацию по-умолчанию из: "%1$s"';
$strConfigFileError = 'phpMyAdmin не может прочитать данные из конфигурационного файла!  <br />Возможная причина - синтаксическая ошибка.<br />Вызовите этот файл (config.inc.php) непосредственно из браузера. Если будут сообщения об ошибках - исправьте их. Если пустая страница - все в порядке';
$strConfigureTableCoord = 'Измените координаты таблицы %s';
$strConnectionError = 'Соединение невозможно: неверные устоновки.';
$strConnections = 'Соединения';
$strConstraintsForDumped = 'Constraints for dumped tables';
$strConstraintsForTable = 'Constraints for table';
$strCookiesRequired = 'Cookies должны быть включены после этого места.';
$strCopy = 'Копировать';
$strCopyDatabaseOK = 'БД %s была скопирована в %s';
$strCopyTable = 'Скопировать таблицу в (база данных<b>.</b>таблица):';
$strCopyTableOK = 'Таблица %s была скопирована в %s.';
$strCopyTableSameNames = ' Не могу скопировать таблицу саму в себя !';
$strCouldNotKill = 'phpMyAdmin не смог удалить thread %s. Возможно, он уже закрыт.';
$strCreate = 'Создать';
$strCreateDatabaseBeforeCopying = 'CREATE DATABASE перед копированием';
$strCreateIndex = 'Создать индекс на&nbsp;%s&nbsp;колонках';
$strCreateIndexTopic = 'Создать новый индекс';
$strCreateNewDatabase = 'Новая база данных';
$strCreateNewTable = 'Создать новую таблицу в БД %s';
$strCreatePage = 'Создать новую страницу';
$strCreatePdfFeat = 'Создание PDF-схемы';
$strCreateUserDatabase = 'База данных для пользователя';
$strCreateUserDatabaseName = 'Создать базу данных с таким-же именем и предоставить все привелегии';
$strCreateUserDatabaseNone = 'Не создавать';
$strCreateUserDatabaseWildcard = 'Предоставить все привелегии по маске (username\_%)';
$strCreationDates = 'Создание/Обновление/Проверка дат';
$strCriteria = 'Критерий';
$strCroatian = 'Хорватский';
$strCSV = 'CSV';
$strCSVImportOptions = 'Параметры CSV';
$strCSVOptions = 'Параметры CSV';
$strCyrillic = 'Кириллический';
$strCzech = 'Чешский';
$strCzechSlovak = 'Чешский';

$strDanish = 'Датский';
$strData = 'Данные';
$strDatabase = 'База данных';
$strDatabaseEmpty = 'Имя базы данных не указанно!';
$strDatabaseExportOptions = 'Параметры экспорта базы данных';
$strDatabaseHasBeenDropped = 'База данных %s была удалена.';
$strDatabaseNoTable = 'Эта БД не содержит таблиц!';
$strDatabases = 'Базы данных';
$strDatabasesDropped = '%s БД были успешно удалены.';
$strDatabasesStats = 'Статистика баз данных';
$strDatabasesStatsDisable = 'Отключить статистику';
$strDatabasesStatsEnable = 'Включить статистику';
$strDatabasesStatsHeavyTraffic = 'Замечание: Включение статистики базы данных может спровоцировать большой трафик между веб-сервером и сервером MySQL.';
$strDataDict = 'Словарь данных';
$strDataOnly = 'Только данные';
$strDataPages = 'Страниц с данными';
$strDBComment = 'Комментарий БД: ';
$strDBCopy = 'Скопировать БД в';
$strDbPrivileges = ' Привилегии, специфичные для базы данных';
$strDBRename = 'Переименовать базу данных в';
$strDbSpecific = 'специфично для БД';
$strDefault = 'По умолчанию';
$strDefaultValueHelp = 'Для значений по умолчанию просто введите единственное значение без экранирования и квотирования, используя этот формат: a';
$strDefragment = 'Дефрагментировать таблицу';
$strDelayedInserts = 'Использовать отложенные вставки';
$strDelete = 'Удалить';
$strDeleteAndFlush = 'Удалить всех пользователей и перезагрузить привилегии.';
$strDeleteAndFlushDescr = 'Это лучший способ, но перезагрузка привилегий может занять некоторое время.';
$strDeleted = 'Ряд был удален';
$strDeletedRows = 'Следующие ряды были удалены:';
$strDeleteNoUsersSelected = 'Пользователей для удаления не выбранно!';
$strDeleting = 'Удаление %s';
$strDelimiter = 'Разделитель';
$strDelOld = 'В текущей странице есть ссылки на таблицы, котрые больше не существуют. Вы хотите удалить эти ссылки?';
$strDescending = 'По убыванию';
$strDescription = 'Описание';
$strDictionary = 'словарь';
$strDirtyPages = 'Грязные страницы';
$strDisabled = 'Недоступно';
$strDisableForeignChecks = 'Выключить проверку инородных ключей';
$strDisplayFeat = 'Показать дополнительные возможности';
$strDisplayOrder = 'Порядок просмотра:';
$strDisplayPDF = 'Показать PDF-схему';
$strDoAQuery = 'Выполнить "запрос по примеру" (символ подстановки: "%")';
$strDocu = 'Документация';
$strDoYouReally = 'Вы действительно желаете ';
$strDrop = 'Уничтожить';
$strDropDatabaseStrongWarning = 'Вы уверенны что хотите уничтожить всю базу данных?';
$strDropUsersDb = 'Удалить базы, которые имеют такие же имена как и пользователи.';
$strDumpingData = 'Дамп данных таблицы';
$strDumpSaved = 'Дамп сохранён в файл %s.';
$strDumpXRows = 'Дамп %s записей, начиная с %s.';
$strDynamic = 'динамический';

$strEdit = 'Правка';
$strEditPDFPages = 'Изменить PDF-страницы';
$strEditPrivileges = 'Редактирование привилегий';
$strEffective = 'Эффективность';
$strEmpty = 'Очистить';
$strEmptyResultSet = 'MySQL вернула пустой результат (т.е. ноль рядов).';
$strEnabled = 'Доступно';
$strEncloseInTransaction = 'Экспортировать при переводе';
$strEnd = 'Конец';
$strEndCut = 'END CUT';
$strEndRaw = 'END RAW';
$strEngines = 'Хранилища';
$strEnglish = 'Английский';
$strEnglishPrivileges = ' Примечание: привилегии MySQL задаются по-английски ';
$strError = 'Ошибка';
$strErrorInZipFile = 'Ошибка в ZIP-архиве:';
$strErrorRenamingTable = 'Ошибка при переименовании таблицы %1$s в %2$s';
$strEsperanto = 'Эсперанто';
$strEstonian = 'Эстонский';
$strExcelEdition = 'Excel-публикация';
$strExcelOptions = 'Параметры Excel';
$strExecuteBookmarked = 'Выполнить отмеченный запрос';
$strExplain = 'Описать SQL';
$strExport = 'Экспорт';
$strExtendedInserts = 'Расширенные вставки';
$strExtra = 'Дополнительно';

$strFailedAttempts = 'Неудачные попытки';
$strField = 'Поле';
$strFieldHasBeenDropped = 'Поле %s было удалено';
$strFields = 'Поля';
$strFieldsEmpty = ' Пустой счетчик полей! ';
$strFieldsEnclosedBy = 'Поля заключены в';
$strFieldsEscapedBy = 'Поля экранируются';
$strFieldsTerminatedBy = 'Поля разделены';
$strFileAlreadyExists = 'Файл %s уже существует на сервере, измените имя или воспользуйтесь опцией перезаписи.';
$strFileCouldNotBeRead = 'Файл не может быть прочитан';
$strFileNameTemplate = 'Шаблон имени файла';
$strFileNameTemplateDescriptionDatabase = 'имя базы данных';
$strFileNameTemplateDescriptionServer = 'имя сервера';
$strFileNameTemplateDescriptionTable = 'имя таблицы';
$strFileNameTemplateRemember = 'запомнить шаблон';
$strFileToImport = 'Файл для импорта';
$strFixed = 'фиксированный';
$strFlushPrivilegesNote = 'Замечание: phpMyAdmin получает пользовательские привилегии прямо из таблиц привилегий MySQL. Содержимое этих таблиц может отличаться от от привилегий, которые использует сервер, если изменения были внесены вручную. В этом случае вы должны %sперезагрузить привилегии%s перед продолжением работы.';
$strFlushQueryCache = 'Дефрагментировать кэш запросов';
$strFlushTable = 'Сбросить кэш таблицы ("FLUSH")';
$strFlushTables = 'Закрыть все таблицы';
$strFontSize = 'Размер шрифта';
$strFormat = 'Формат';
$strFormEmpty = 'Требуется значение для формы!';
$strFullText = 'Полнотекстовый';
$strFunction = 'Функция';
$strFunctions = 'Функции';

$strGenBy = 'Созданный';
$strGeneralRelationFeat = 'Основные возможности связей';
$strGenerate = 'Сгенерировать';
$strGeneratePassword = 'Сгенерировать пароль';
$strGenTime = 'Время создания';
$strGeorgian = 'Грузинский';
$strGerman = 'Немецкий';
$strGlobal = 'global';
$strGlobalPrivileges = 'Глобальные привилегии';
$strGlobalValue = 'Глобальное значение';
$strGo = 'Пошел';
$strGrantOption = 'Предоставлять';
$strGreek = 'Греческий';
$strGzip = 'архивировать в gzip';

$strHandler = 'Обработчик';
$strHasBeenAltered = 'была изменена.';
$strHasBeenCreated = 'была создана.';
$strHaveToShow = 'Вы должны выбрать не менее одной колонки для отображения';
$strHebrew = 'Иврит';
$strHexForBinary = 'Использовать шестнадцатиричные (hexadecimal) бинарные поля';
$strHome = 'К началу';
$strHomepageOfficial = 'Официальная страница phpMyAdmin';
$strHost = 'Хост';
$strHostEmpty = 'Пустое имя хоста!';
$strHTMLExcel = 'Microsoft Excel 2000';
$strHTMLExcelOptions = 'Параметры экпорта в Microsoft Excel 2000';
$strHTMLWord = 'Microsoft Word 2000';
$strHTMLWordOptions = 'Параметры экпорта в Microsoft Word 2000';
$strHungarian = 'Венгерский';

$strIcelandic = 'Исландский';
$strId = 'ID';
$strIdxFulltext = 'ПолнТекст';
$strIgnore = 'Игнорировать';
$strIgnoreDuplicates = 'Игнорировать повторяющиеся строки';
$strIgnoreInserts = 'Игнорировать вставки';
$strImport = 'Импорт';
$strImportFiles = 'Импорт файлов';
$strImportFormat = 'Формат импортируемого файла';
$strImportSuccessfullyFinished = 'Импорт успешно завершен, запросов выполнено: %d.';
$strIndex = 'Индекс';
$strIndexes = 'Индексы';
$strIndexHasBeenDropped = 'Индекс %s был удален';
$strIndexName = 'Имя индекса&nbsp;:';
$strIndexType = 'Тип индекса&nbsp;:';
$strIndexWarningMultiple = 'Больше одного %s ключа создано для колонки `%s`';
$strIndexWarningTable = 'Проблемы с индексами таблицы `%s`';
$strInnoDBDataFilePath = 'Файлы данных';
$strInnoDBDataHomeDir = 'Домашний каталог для данных';
$strInnoDBDataHomeDirDesc = 'Общая части пути к каталогу для всех файлов данных InnoDB.';
$strInnoDBPages = 'страницы';
$strInnodbStat = 'Состояние InnoDB';
$strInsecureMySQL = 'Ваш конфигурационный файл содержит настройки (пользователь root без пароля), которые относятся к привилегированному пользователю MySQL (по умолчанию). Ваш MySQL сервер запущен с этими настройками по умолчанию, открытый для вторжений, поэтому Вам настоятельно рекомендуется устранить эту дыру в безопасности.';
$strInsert = 'Вставить';
$strInsertAsNewRow = 'Вставить новый ряд';
$strInsertedRowId = 'Вставить id ряда:';
$strInsertedRows = 'Добавлены ряды:';
$strInternalNotNecessary = '* Внутренняя связь не обязательна, когда она также существует в InnoDB.';
$strInternalRelations = 'Внутренние связи';
$strInUse = 'используется';
$strInvalidColumn = 'Указана неправильная колонка (%s)';
$strInvalidColumnCount = 'Количество колонок должно быть больше нуля.';
$strInvalidCSVFieldCount = 'Неправильное количество полей во входных CSV-данных в строке %d.';
$strInvalidCSVFormat = 'Неправильный формат входных CSV-данных в строке %d.';
$strInvalidCSVParameter = 'Неправильный параметр импорта CSV: %s';
$strInvalidDatabase = 'Неправильная база данных'; 
$strInvalidFieldAddCount = 'Вы должны добвить хотя бы одно поле.';
$strInvalidFieldCount = 'У таблицы должно быть хотя бы одно поле.';
$strInvalidRowNumber = 'Число %d не является правильным номером строки.';
$strInvalidTableName = 'Неправильное имя таблицы';

$strJapanese = 'Японский';
$strJoins = 'Объединения';
$strJumpToDB = 'Перейти к базе &quot;%s&quot;.';
$strJustDelete = 'Просто удалить пользователей из таблиц привилегий.';
$strJustDeleteDescr = '&quot;Удаленные&quot; пользователи все еще смогут работать с сервером как обычно до перезагрузки привилегий.';

$strKeepPass = 'Не менять пароль';
$strKeyCache = 'Кэш ключей';
$strKeyname = 'Имя ключа';
$strKill = 'Убить';
$strKorean = 'Корейский';

$strLandscape = 'Ландшафт';
$strLanguage = 'Язык';
$strLanguageFileNotFound = 'Языковой файл: "%1$s" не найден.';
$strLanguageUnknown = 'Неизвестный язык: %1$s.';
$strLaTeX = 'LaTeX';
$strLatexCaption = 'Заголовок таблицы';
$strLatexContent = 'Содержимое таблицы __TABLE__';
$strLatexContinued = '(продолжено)';
$strLatexContinuedCaption = 'Продолженный заголовок таблицы';
$strLatexIncludeCaption = 'Включить заголовок таблицы';
$strLaTeXOptions = 'Параметры LaTeX';
$strLatexStructure = 'Структура таблицы __TABLE__';
$strLatvian = 'Латвийский';
$strLDI = 'CSV используя LOAD DATA';
$strLDIImportOptions = 'Параметры для импорта CSV используя LOAD DATA';
$strLengthSet = 'Длины/Значения*';
$strLimitNumRows = 'записей на страницу';
$strLinesTerminatedBy = 'Строки разделены';
$strLinkNotFound = 'Связь не найдена';
$strLinksTo = 'Связь с';
$strLithuanian = 'Литовский';
$strLocalhost = 'Локальный';
$strLocationTextfile = 'Месторасположение текстового файла';
$strLogin = 'Вход в систему';
$strLoginInformation = 'Информация логина';
$strLogout = 'Выйти из системы';
$strLogPassword = 'Пароль:';
$strLogServer = 'Сервер';
$strLogUsername = 'Пользователь:';

$strMaximalQueryLength = 'Максимальная длина создаваемого запроса';
$strMaximumSize = 'Максимальный размер: %s%s';
$strMIME_available_mime = 'Доступные MIME-типы';
$strMIME_available_transform = 'Доступные трансформации';
$strMIME_description = 'Описание';
$strMIME_MIMEtype = 'MIME-тип';
$strMIME_nodescription = 'Нет доступных описаний для этой трансформации.<br />Пожалуйста, спросите автора что делает %s.';
$strMIME_transformation = 'Трансформация браузера';
$strMIME_transformation_note = 'Для списка доступных опций трансформации и трансформаций их MIME-типов кликните на %sописание трансформаций%s';
$strMIME_transformation_options = 'Параметры трансформации';
$strMIME_transformation_options_note = 'Пожалуйсиа, введите значения для трансформации, используя этот формат: \'a\', 100, b,\'c\'...<br />Если вам нужно поставить бэкслэш("\") или кавычку("\'"), экранируйте их (например \'\\\\xyz\' or \'a\\\'b\').';
$strMIME_without = 'MIME-типы, выделенные курсивом, не имеют отдельной функции трансформации';
$strMIMETypesForTable = 'MIME-типы таблицы';
$strModifications = 'Модификации были сохранены';
$strModify = 'Изменить';
$strModifyIndexTopic = 'Изменить индекс';
$strMoveTable = 'Переместить таблицы в (база данных<b>.</b>таблица):';
$strMoveTableOK = 'Таблица %s была перемещена в %s.';
$strMoveTableSameNames = 'Не могу переместить таблицу саму в себя!';
$strMultilingual = 'многоязычный';
$strMySQLCharset = 'MySQL-кодировка';
$strMysqlClientVersion = 'Версия MySQL-клиента';
$strMySQLConnectionCollation = 'Сопоставление соединения с MySQL';
$strMySQLSaid = 'Ответ MySQL: ';
$strMySQLShowProcess = 'Показать потоки';
$strMySQLShowStatus = 'Показать состояние';
$strMySQLShowVars = 'Показать системные переменные';

$strName = 'Имя';
$strNext = 'Далее';
$strNo = 'Нет';
$strNoDatabases = 'БД отсутствуют';
$strNoDatabasesSelected = 'Ни одна БД не выбрана.';
$strNoDataReceived = 'Не получено данных для импорта. Либо файл не был выбран либо размер файла превышает максимальный размер, разрешённый в вашей конфигурации PHP. См. FAQ 1.16';
$strNoDescription = 'нет описания';
$strNoDropDatabases = 'Команда "Удалить БД" отключена.';
$strNoExplain = 'Прекратить описание SQL';
$strNoFilesFoundInZip = 'Файлов внутри ZIP-архива не найдено!';
$strNoFrames = 'Для работы phpMyAdmin нужен браузер с поддержкой <b>фреймов</b>.';
$strNoIndex = 'Индекс не определен!';
$strNoIndexPartsDefined = 'Части индекса не определены!';
$strNoModification = 'Нет изменений';
$strNone = 'Нет';
$strNoOptions = 'В этом формате нет опций';
$strNoPassword = 'Без пароля';
$strNoPermission = 'Веб-серверу не хватает прав для сохранения файла %s.';
$strNoPhp = 'без PHP-кода';
$strNoPrivileges = 'Без привилегий';
$strNoRights = 'Вы не имеете достаточно прав для этого!';
$strNoRowsSelected = 'Строка таблицы не выбрана';
$strNoSpace = 'Не хватает дискового пространства для сохранения файла %s.';
$strNoTablesFound = 'В БД не обнаружено таблиц.';
$strNotNumber = 'Это не число!';
$strNotOK = 'Не готово';
$strNotSet = 'Таблица <b>%s</b> не найдена';
$strNoUsersFound = 'Не найден пользователь.';
$strNoValidateSQL = 'Не проверять SQL';
$strNull = 'Ноль';
$strNumberOfFields = 'Количество полей';
$strNumSearchResultsInTable = '%s записи(ей) в таблице <i>%s</i>';
$strNumSearchResultsTotal = '<b>Итого:</b> <i>%s</i> записи(ей)';
$strNumTables = 'Таблицы';

$strOK = 'Готово';
$strOpenDocumentText = 'Open Document Text';
$strOpenDocumentTextOptions = 'Параметры Open Document Text';
$strOpenNewWindow = 'Новое окно phpMyAdmin';
$strOperations = 'Операции';
$strOperator = 'Оператор';
$strOptimizeTable = 'Оптимизировать таблицу';
$strOr = 'Или';
$strOverhead = 'Накладные расходы';
$strOverwriteExisting = 'Перезаписать существующий(е) файл(ы)';

$strPageNumber = 'Номер страницы:';
$strPaperSize = 'Размер бумаги';
$strPartialImport = 'Частичный импорт';
$strPartialText = 'Частичные тексты';
$strPassword = 'Пароль';
$strPasswordChanged = 'Пароль для %s был успешно изменён.';
$strPasswordEmpty = 'Пустой пароль!';
$strPasswordNotSame = 'Пароли не одинаковы!';
$strPDF = 'PDF';
$strPdfDbSchema = 'Структура базы "%s" - страница %s';
$strPdfInvalidTblName = 'Таблица "%s" не существует!';
$strPdfNoTables = 'Нет таблиц';
$strPDFOptions = 'Параметры PDF';
$strPDFReportExplanation = '(Создание отчёта, содержащего данный одной таблицы)';
$strPerHour = 'в час';
$strPerMinute = 'в минуту';
$strPerSecond = 'в секунду';
$strPersian = 'Персидский';
$strPhoneBook = 'телефонная книга';
$strPhp = 'Создать PHP-код';
$strPHP40203 = 'Вы используете версию PHP 4.2.3, которая содержит серьезные ошибки при работе с много-байтовыми строками (mbstring). Смотрите PHP bug report 19404. Данная версия PHP не рекомендуется для использования с phpMyAdmin.';
$strPHPVersion = 'Версия PHP';
$strPmaDocumentation = 'Документация по phpMyAdmin';
$strPmaUriError = 'Директива <tt>$cfg[\'PmaAbsoluteUri\']</tt> должна быть установлена в Вашем конфигурационном файле!';
$strPolish = 'Польский';
$strPortrait = 'Портрет';
$strPos1 = 'Начало';
$strPrevious = 'Назад';
$strPrimary = 'Первичный';
$strPrimaryKeyHasBeenDropped = 'Первичный ключ был удален';
$strPrimaryKeyName = 'Имя первичного ключа должно быть PRIMARY!';
$strPrimaryKeyWarning = '("PRIMARY" <b>должно</b> быть признаком <b>только</b> первичного ключа!)';
$strPrint = 'Печать';
$strPrintView = 'Версия для печати';
$strPrintViewFull = 'Распечатать (со всем текстом)';
$strPrivDescAlter = 'Позволяет изменение структуры существующих таблиц.';
$strPrivDescCreateDb = 'Позволяет создание новых баз данных и таблиц.';
$strPrivDescCreateTbl = 'Позволяет создание новых таблиц.';
$strPrivDescCreateTmpTable = 'Позволяет создание временных таблиц.';
$strPrivDescDelete = 'Позволяет удаление данных.';
$strPrivDescDropDb = 'Позволяет удаление ';
$strPrivDescDropTbl = 'Позволяет удаление таблиц.';
$strPrivDescExecute = 'Позволяет запуск хранимых процедур; Не работает в этой версии MySQL.';
$strPrivDescFile = 'Позволяет импортирование и экспортирование данных в файлы.';
$strPrivDescGrant = 'Позволяет добавление пользователей и привилегий без перезагрузки таблиц привилегий.';
$strPrivDescIndex = 'Позволяет создание и удаление индексов.';
$strPrivDescInsert = 'Позволяет вставку и замену данных.';
$strPrivDescLockTables = 'Позволяет блокировку таблиц для текущего потока.';
$strPrivDescMaxConnections = 'Ограничивает количество соединений, которые пользователь может открыть в течение часа.';
$strPrivDescMaxQuestions = 'Ограничивает количество запросов, которые пользователь может отравит в течение часа.';
$strPrivDescMaxUpdates = 'Ограничивает количество команд, изменяющих любую таблицу или базу данных, которые пользователь может выполнить за час.';
$strPrivDescProcess3 = 'Позволяет убивать процессы других пользоваетелей.';
$strPrivDescProcess4 = 'Позволяет просмотр полных запросов в списке процессов.';
$strPrivDescReferences = 'Не работает в этой версии MySQL.';
$strPrivDescReload = 'Позволяет перезагрузку настроек сервера и очистку его кэшей.';
$strPrivDescReplClient = 'Даёт пользователю право спрашивать где находяться slaves / masters.';
$strPrivDescReplSlave = 'Нужен для репликации slaves.';
$strPrivDescSelect = 'Позволяет чтение данных.';
$strPrivDescShowDb = 'Даёт доступ к полному списку баз данных.';
$strPrivDescShutdown = 'Позволяет остановку сервера.';
$strPrivDescSuper = 'Позволяет соединяться, даже если достигнуто максимальное количество соединений; Необходимо для большинства административных задач, таких как установка глобальных переменных или остановка процессов других пользователей.';
$strPrivDescUpdate = 'Позволяет изменение данных.';
$strPrivDescUsage = 'Нет привилегий.';
$strPrivileges = 'Привилегии';
$strPrivilegesReloaded = 'Привилегии были успешно перезагружены.';
$strProcedures = 'Процедуры';
$strProcesses = 'Процессы';
$strProcesslist = 'Список процессов';
$strProtocolVersion = 'Версия протокола';
$strPutColNames = 'Укажите наименования полей в первой строке';

$strQBE = 'Запрос&nbsp;по&nbsp;примеру';
$strQBEDel = 'Удалить';
$strQBEIns = 'Вставить';
$strQueryCache = 'Кэш запросов';
$strQueryFrame = 'Окно запроса';
$strQueryOnDb = 'SQL-запрос БД <b>%s</b>:';
$strQueryResultsOperations = 'Действия над результатами запроса';
$strQuerySQLHistory = 'История SQL';
$strQueryStatistics = '<b>Статистика запросов</b>: Со времени запуска %s запросов было послано на сервер.';
$strQueryTime = 'Запрос занял %01.4f сек';
$strQueryType = 'Тип запроса';
$strQueryWindowLock = 'Не перезаписывать этот запрос вне окна';

$strReceived = 'Принято';
$strRecords = 'Записи';
$strReferentialIntegrity = 'Проверить целостность данных:';
$strRefresh = 'Обновить';
$strRelationalSchema = 'Реляционная схема';
$strRelationNotWorking = 'Дополнительные возможности для работы со связанными таблицами недоступны. Для определения причины нажмите %sсюда%s.';
$strRelations = 'Связи';
$strRelationsForTable = 'Соотношения в таблице';
$strRelationView = 'Связанный вид';
$strReloadingThePrivileges = 'Перезагрузка привилегий';
$strReloadPrivileges = 'Перезагрузить привилегии';
$strRemoveSelectedUsers = 'Удалить выделенных пользователей';
$strRenameDatabaseOK = 'База данных %s переименована в %s';
$strRenameTable = 'Переименовать таблицу в';
$strRenameTableOK = 'Таблица %s была переименована в %s';
$strRepairTable = 'Починить таблицу';
$strReplaceNULLBy = 'Заменить NULL на';
$strReplaceTable = 'Заместить данные таблицы данными из файла';
$strReplication = 'Репликация';
$strReset = 'Переустановить';
$strResourceLimits = 'Ограничения ресурсов пользователя';
$strReType = 'Подтверждение';
$strRevoke = 'Отменить';
$strRevokeAndDelete = 'Отменить все активные привилегии пользователей и затем удалить их.';
$strRevokeAndDeleteDescr = 'Пользователи всё ещё будут иметь USAGE привилегии до перезагрузки привилегий.';
$strRevokeMessage = 'Вы изменили привилегии для %s';
$strRomanian = 'Румынский';
$strRowLength = 'Длина ряда';
$strRows = 'Ряды';
$strRowsFrom = 'рядов от';
$strRowSize = ' Размер ряда ';
$strRowsModeFlippedHorizontal = 'горизонтально (повернутые заголовки)';
$strRowsModeHorizontal = 'горизонтальном';
$strRowsModeOptions = 'в %s режиме, заголовки после каждых %s ячеек';
$strRowsModeVertical = 'вертикальном';
$strRowsStatistic = 'Статистика ряда';
$strRunning = 'на %s';
$strRunQuery = 'Выполнить Запрос';
$strRunSQLQuery = 'Выполнить SQL запрос(ы) на БД %ы';
$strRunSQLQueryOnServer = 'Запустить SQL запрос(ы) на сервере %s';
$strRussian = 'Русский';

$strSave = 'Сохранить';
$strSaveOnServer = 'Сохранить на сервере в директории %s';
$strScaleFactorSmall = 'Масштаб слишком маленький для отображения всей таблицы на одной странице';
$strSearch = 'Искать';
$strSearchFormTitle = 'Искать в базе данных';
$strSearchInTables = 'В таблице(ах):';
$strSearchNeedle = 'Слово(а) или значение(я) для поиска (включая "%") в:';
$strSearchOption1 = 'хоть одно слово';
$strSearchOption2 = 'все слова';
$strSearchOption3 = 'точное соответствие';
$strSearchOption4 = 'регулярное выражение';
$strSearchResultsFor = 'Искать в "<i>%s</i>" %s:';
$strSearchType = 'Искать:';
$strSecretRequired = 'Конфигурационному файлу сейчас нужна секретная фраза (blowfish_secret).';
$strSelectADb = 'Пожалуйста, выберите базу данных';
$strSelectAll = 'Отметить все';
$strSelectFields = 'Выбрать поля (минимум одно):';
$strSelectNumRows = 'по запросу';
$strSelectTables = 'Выберите таблицу(ы)';
$strSend = 'послать';
$strSent = 'Послано';
$strServer = 'Сервер';
$strServerChoice = 'Выбор сервера';
$strServerNotResponding = 'Сервер не отвечает';
$strServers = 'Сервера';
$strServerStatus = 'Текущая информация';
$strServerStatusDelayedInserts = 'Отложенные вставки';
$strServerStatusUptime = 'Этот MySQL сервер работает %s. Он был запущен %s.';
$strServerTabVariables = 'Переменные';
$strServerTrafficNotes = '<b>Трафик</b>: Эти таблицы показывают статистику по сетевому трафику MySQL сервера со времени его запуска.';
$strServerVars = 'Переменные и настройки сервера';
$strServerVersion = 'Версия сервера';
$strSessionValue = 'Значение сессии';
$strSetEnumVal = 'Для типов поля "enum" и "set", введите значения по этому формату: \'a\',\'b\',\'c\'...<br />Если вам понадобиться ввести обратную косую черту ("\"") или одиночную кавычку ("\'") среди этих значений, поставьте перед ними обратную косую черту (например, \'\\\\xyz\' или \'a\\\'b\').';
$strShow = 'Показать';
$strShowAll = 'Показать все';
$strShowColor = 'Показать цвет';
$strShowDatadictAs = 'Формат словаря данных';
$strShowFullQueries = 'Показывать Полные Запросы';
$strShowGrid = 'Показать сетку';
$strShowingRecords = 'Показывает записи ';
$strShowOpenTables = 'Список открытых таблиц';
$strShowPHPInfo = 'Показать информацию о PHP';
$strShowSlaveHosts = 'Список подчиненных серверов';
$strShowSlaveStatus = 'Состояние подчиненных серверов';
$strShowStatusCreated_tmp_disk_tablesDescr = 'Количество неявных временных таблиц на диске, созданных во время выполнения операторов. Если значение Created_tmp_disk_tables велико, возможно, необходимо увеличить значение переменной tmp_table_size, чтобы временные таблицы располагались в памяти, а не на жестком диске.';
$strShowStatusCreated_tmp_filesDescr = 'Количество созданных временных файлов mysqld.';
$strShowStatusCreated_tmp_tablesDescr = 'Количество неявных временных таблиц в памяти, созданных во время выполнения операторов.';
$strShowStatusDelayed_errorsDescr = 'Количество записанных при помощи команды INSERT DELAYED строк, в которых произошли какие-либо ошибки (возможно, из-за дублирования ключей).';
$strShowStatusDelayed_insert_threadsDescr = 'Количество используемых потоков-обработчиков INSERT DELAYED. Для каждая таблице в которой используется INSERT DELAYED получает отдельный поток.';
$strShowStatusDelayed_writesDescr = 'Количество строк, записанных INSERT DELAYED.';
$strShowStatusFlush_commandsDescr  = 'Количество выполненных команд FLUSH.';
$strShowStatusHandler_commitDescr = 'Количество внутренних команд COMMIT.';
$strShowStatusHandler_deleteDescr = 'Количество удалений строк из таблицы.';
$strShowStatusHandler_read_firstDescr = 'Количество считываний из индекса первой записи. Если это значение высокое, то, по всей вероятности, сервер осуществляет много полных индексных сканирований, например, SELECT col1 FROM foo, предполагая, что col1 проиндексирован.';
$strShowStatusHandler_read_keyDescr = 'Количество запросов на чтение строки, основанных на ключе. Высокое значение переменной говорит о том, что ваши запросы и таблицы проиндексированы надлежащим образом.';
$strShowStatusHandler_read_nextDescr = 'Количество запросов на чтение следующей строки в порядке расположения ключей. Это значение будет увеличиваться, если производится запрос индексного столбца с ограничением по размеру. Значение также увеличивается во время проведения индексного сканирования.';
$strShowStatusHandler_read_prevDescr = 'Количество запросов на чтение предыдущей строки в порядке расположения ключей. В большинстве случаев используется для оптимизации ORDER BY ... DESC.';
$strShowStatusHandler_read_rnd_nextDescr = 'Количество запросов на чтение следующей строки из файла данных. Данное значение будет высоким, если производится много сканирований таблиц. Обычно это означает, что ваши таблицы не проиндексированы надлежащим образом или ваши запросы не используют преимущества индексов.';
$strShowStatusHandler_read_rndDescr = 'Количество запросов на чтение строки, основанных на фиксированной позиции. Значение будет высоким, если выполняется много запросов, требующих сортировки результатов. Возможно вы используете много запросов вынуждающих MySQL производить полное сканирование таблиц или у вас есть объединения не использующие индексы надлежащим образом.';
$strShowStatusHandler_rollbackDescr = 'Количество внутренних команд ROLLBACK.';
$strShowStatusHandler_updateDescr = 'Количество запросов на обновление строки в таблице.';
$strShowStatusHandler_writeDescr = 'Количество запросов на вставку строки в таблицу.';
$strShowStatusKey_blocks_not_flushedDescr = 'Блоки ключей в кэше ключей, которые были изменены, но еще не записаны на диск. Параметр также известен под именем Not_flushed_key_blocks.';
$strShowStatusKey_blocks_unusedDescr = 'Количество неиспользуемых блоков в кэше ключей. Вы можете использовать это значения для определения насколько используется кэш ключей';
$strShowStatusKey_blocks_usedDescr = 'Количество используемых блоков в кэше ключей. Это значение представляет собой максимальное количество блоков когда-либо использованных одновременно.';
$strShowStatusKey_read_requestsDescr = 'Количество запросов на чтение блока ключей из кэша.';
$strShowStatusKey_readsDescr = 'Количество физических считываний блока ключей с диска. Если значение Key_reads велико, возможно, что значение переменной key_buffer_size слишком мало. Частоту неуспешных обращений к кэшу можно вычислить так: Key_reads/Key_read_requests.';
$strShowStatusKey_write_requestsDescr = 'Количество запросов на запись блока ключей в кэш.';
$strShowStatusKey_writesDescr = 'Количество физических записей блоков ключей на диск.';
$strShowStatusNot_flushed_delayed_rowsDescr = 'Количество строк, стоящих в очереди на запись в запросах INSERT DELAYED.';
$strShowStatusOpen_filesDescr = 'Количество открытых файлов.';
$strShowStatusOpen_streamsDescr = 'Количество открытых потоков (в основном используется для журналирования).';
$strShowStatusOpen_tablesDescr = 'Количество открытых таблиц.';
$strShowStatusOpened_tablesDescr = 'Количество открывавшихся таблиц. Если значение Opened_tables велико, возможно, что значение переменной table_cache слишком мало.';
$strShowStatusQcache_free_blocksDescr = 'Количество свободных блоков памяти в кэше запросов.';
$strShowStatusQcache_free_memoryDescr = 'Величина свободной памяти для кэша запросов.';
$strShowStatusQcache_hitsDescr = 'Количество результативных обращений в кэш.';
$strShowStatusQcache_insertsDescr = 'Количество запросов, добавленных в кэш.';
$strShowStatusQcache_lowmem_prunesDescr = 'Количество запросов,  которые были удалены из кеша для освобождения памяти под новые результаты запросов. Эта информация может помочь вам настроить размер кэша запросов. Кеш запросов использует стратегию используется реже всего (least recently used, LRU) для принятия решений о о том, какие запросы удалить из кеша.';
$strShowStatusQcache_not_cachedDescr = 'Количество не кэшированных запросов (не подлежащих кэшированию или из-за установок QUERY_CACHE_TYPE).';
$strShowStatusQcache_queries_in_cacheDescr = 'Количество запросов, зарегистрированных в кэше.';
$strShowStatusQcache_total_blocksDescr = 'Общее количество блоков в кэше запросов.';
$strShowStatusReset = 'Сбросить';
$strShowStatusRpl_statusDescr = 'Состояние отказобезопасной репликации (пока не реализовано).';
$strShowStatusSelect_full_joinDescr = 'Количество объединений без использования индексов. Если это значение равно 0, вам следует внимательно проверить индексы ваших таблиц.';
$strShowStatusSelect_full_range_joinDescr = 'Количество объединений, где был использован поиск по диапазону в справочной таблице.';
$strShowStatusSelect_range_checkDescr = 'Количество объединений без ключей, в которых проверка использования ключей производится после каждой строки. Если это значение равно 0, вам следует внимательно проверить индексы ваших таблиц.';
$strShowStatusSelect_rangeDescr = 'Количество объединений, в которых использовались диапазоны в первой таблице. Обычно это значение не критично, даже если оно велико.';
$strShowStatusSelect_scanDescr = 'Количество объединений, в которых проводилось полное сканирование первой таблицы.';
$strShowStatusSlave_open_temp_tablesDescr = 'Количество временных таблиц, открытых в настоящий момент потоком подчиненного компьютера.';
$strShowStatusSlave_retried_transactionsDescr = 'Общее количество (с момента запуска) повторов транзацкий потоком подчиненного компьютера.';
$strShowStatusSlave_runningDescr = 'Содержит значение ON, если это подчиненный компьютер, подключенный к головному компьютеру.';
$strShowStatusSlow_launch_threadsDescr = 'Количество потоков, создание которых заняло больше, чем slow_launch_time секунд.';
$strShowStatusSlow_queriesDescr = 'Количество запросов, обработка которых заняла больше времени, чем long_query_time секунд.';
$strShowStatusSort_merge_passesDescr = 'Количество объединений, осуществленных алгоритмом сортировки. Если это значение велико, следует увеличить значение переменной sort_buffer_size.';
$strShowStatusSort_rangeDescr = 'Количество сортировок, которые осуществлялись в диапазонах.';
$strShowStatusSort_rowsDescr = 'Количество отсортированных строк.';
$strShowStatusSort_scanDescr = 'Количество сортировок, осуществленных путем сканирования таблицы.';
$strShowStatusTable_locks_immediateDescr = 'Количество запросов на немедленную блокировку таблицы.';
$strShowStatusTable_locks_waitedDescr = 'Количество запросов, когда немедленная блокировка не могла быть осуществлена и требовалось время на ожидание. Если это значение велико, и у вас есть проблемы с производительностью, сначала необходимо оптимизировать свои запросы, а затем либо разделить таблицы, либо использовать репликацию.';
$strShowStatusThreads_cachedDescr = 'Количество потоков в кэше потоков. Частоту успешных обращений к кэшу можно вычислить по формуле Threads_created/Connections. Если это значение красное, вам следует увеличить thread_cache_size.';
$strShowStatusThreads_connectedDescr = 'Количество открытых в настоящий момент соединений.';
$strShowStatusThreads_createdDescr = 'Количество потоков, созданных для управления соединениями. Если значение Threads_created велико, возможно, необходимо увеличить значение переменной thread_cache_size (обычно это не дает сущесттвенного выигрыша в производительности если вы используете хорошоую реализацию потоков).';
$strShowStatusThreads_runningDescr = 'Количество не простаивающих потоков.';
$strShowTableDimension = 'Показать размерность таблицы';
$strShowTables = 'Показать таблицы';
$strShowThisQuery = ' Показать данный запрос снова ';
$strSimplifiedChinese = 'Упрощённый китайский';
$strSingly = '(отдельно)';
$strSize = 'Размер';
$strSlovak = 'Словацкий';
$strSlovenian = 'Словенский';
$strSort = 'Отсортировать';
$strSortByKey = 'Сортировать по ключу';
$strSorting = 'Сортировка';
$strSpaceUsage = 'Используемое пространство';
$strSpanish = 'Испанский';
$strSplitWordsWithSpace = 'Слова, разделенные пробелом (" ").';
$strSQL = 'SQL';
$strSQLExportType = 'Тип экспорта';
$strSQLImportOptions = 'Параметры SQL';
$strSQLOptions = 'Параметры SQL';
$strSQLParserBugMessage = 'Возможно у Вас ошибка в SQL-парсере. Пожалуйста, проверьте внимательно Ваш запрос и соответствие кавычек. Возможно также, что Вы пытаетесь закачать бинарный файл вне поля quoted text area. Вы можете попробовать выполнить свой запрос через интерфейс командной строки MySQL. Описание ошибки MySQL сервера дано ниже, возможно оно поможет понять, что же произошло. Если у Вас все равно возникают проблемы или если парсер выдает ошибки там, где интерфейс командной строки работает успешно, попробуйте изменить свой SQL запрос до простых запросов и определить, какой именно вызывает проблемы. Вы можете также прислать отчет об ошибке вместе с блоком данных (секция CUT):';
$strSQLParserUserError = 'Кажется возникла ошибка в Вашем SQL запросе. Описание ошибки от MySQL сервера дано ниже, возможно, оно поможет Вам разобраться';
$strSQLQuery = 'SQL-запрос';
$strSQLResult = 'SQL-результат';
$strSQPBugInvalidIdentifer = 'Неправильный идентификатор';
$strSQPBugUnclosedQuote = 'Незакрытая кавычка';
$strSQPBugUnknownPunctuation = 'Неизвестная строка с пунктуацией';
$strStatCheckTime = 'Последняя проверка';
$strStatCreateTime = 'Создание';
$strStatement = 'Выражения';
$strStatUpdateTime = 'Последнее обновление';
$strStatus = 'Состояние';
$strStorageEngines = 'Хранилища';
$strStrucCSV = 'CSV данные';
$strStrucData = 'Структура и данные';
$strStrucExcelCSV = 'CSV для данных MS Excel';
$strStrucNativeExcel = 'Данные из MS Excel';
$strStrucOnly = 'Только структуру';
$strStructPropose = 'Предлагаемая структура таблицы';
$strStructure = 'Структура';
$strSubmit = 'Выполнить';
$strSuccess = 'Ваш SQL-запрос был успешно выполнен';
$strSum = 'Всего';
$strSwedish = 'Шведский';
$strSwitchToDatabase = 'Переключиться на скопированную базу данных';
$strSwitchToTable = 'Переключиться на скопированную таблицу';

$strTable = 'таблица ';
$strTableAlreadyExists = 'Таблица %s уже существует!';
$strTableComments = 'Комментарий к таблице';
$strTableEmpty = 'Пустое название таблицы!';
$strTableHasBeenDropped = 'Таблица %s была удалена';
$strTableHasBeenEmptied = 'Таблица %s была очищена';
$strTableHasBeenFlushed = 'Был сброшен кэш таблицы %s';
$strTableMaintenance = 'Обслуживание таблицы';
$strTableOfContents = 'Оглавление';
$strTableOptions = 'Параметры таблицы';
$strTables = '%s таблиц(ы)';
$strTableStructure = 'Структура таблицы';
$strTakeIt = 'обработать';
$strTblPrivileges = ' Привилегии, специфичные для таблицы';
$strTempData = 'Временные данные';
$strTextAreaLength = ' Из-за большой длины,<br /> это поле не может быть отредактированно ';
$strThai = 'Таи';
$strTheme = 'Тема / Стиль';
$strThemeDefaultNotFound = 'Тема по-умолчанию %s не найдена!';
$strThemeNoPreviewAvailable = 'Предпросмотр не доступен.';
$strThemeNotFound = 'Тема %s не найдена!';
$strThisHost = 'Этот хост';
$strThreads = 'Потоки';
$strThreadSuccessfullyKilled = 'Thread %s был удален.';
$strTime = 'Время';
$strToggleScratchboard = 'toggle scratchboard';
$strTotal = 'всего';
$strTotalUC = 'Всего';
$strTraditionalChinese = 'Традиционный китайский';
$strTraditionalSpanish = 'Традиционный Испанский';
$strTraffic = 'Трафик';
$strTransformation_application_octetstream__download = 'Показать линк к загрузке бинарных данных полей. Первый вариант: укажите имя бинарного файла. Второй вариант: укажите возможное имя строки таблицы в которой находится бинарный файл. Если вы выберете второй вариант, убедитесь в том, что имя бинарного файла  в первом варианте не указанно';
$strTransformation_image_jpeg__inline = 'Отображает предпросмотр, на который можно кликнуть; опции: ширина,высота в пикселах (сохраняет исходный масштаб)';
$strTransformation_image_jpeg__link = 'Отображает ссылку на это изображение (direct blob download, i.e.).';
$strTransformation_image_png__inline = 'См. image/jpeg: inline';
$strTransformation_text_plain__external = 'ТОЛЬКО LINUX: Запускает внешнее приложение и запоняет поля через стандартный ввод. Возвращает стандартный вывод приложения. По умолчанию Tidy, для форматирования HTML кода. По соображениям безопасности, вы должны вручную отредактировать файл libraries/transformations/text_plain__external.inc.php и вписать программы, которые вы хотите запускать. Первая опция - это номер программы, которую вы хотите использовать, вторая - параметры для программы. Третий параметр при значении 1 будет конвертировать вывод, используя htmlspecialchars() (По умолчанию 1). Четвёртый параметр при значении 1 выставит NOWRAP, так что весь вывод будет отображён без переформатирования (По умолчанию 1)';
$strTransformation_text_plain__formatted = 'Сохраняет исходное форматирование поля. Экранирование не производится.';
$strTransformation_text_plain__imagelink = 'Показывает изображение и ссылку, поле содержит имя файла; первая опция - это префикс вроде "http://domain.com/", вторая - ширина в пикселах, третья - высота.';
$strTransformation_text_plain__link = 'Отображает ссылку, поле содержит имя файла; первая опция - это префикс вроде "http://domain.com/", вторая - заголовок для ссылки.';
$strTransformation_text_plain__substr = 'Показывает только часть строки. Первая опция - это сдвиг, определяющий где начинается вывод текста (По умолчанию 0). Вторая опция - это количество возвращаемого текста. Если не определено, то возвращается весь остающийся текст. Третья опция определяет символы, которые будут добавлены к выводу, когда возвращается подстрока. (По умолчанию: ...) .';
$strTruncateQueries = 'Обрезать Показанные Запросы';
$strTurkish = 'Турецкий';
$strType = 'Тип';

$strUkrainian = 'Украинский';
$strUncheckAll = 'Снять отметку со всех';
$strUnicode = 'Юникод';
$strUnique = 'Уникальное';
$strUnknown = 'неизвестно';
$strUnselectAll = 'Снять отметку со всех';
$strUpdatePrivMessage = 'Были изменены привилегии для';
$strUpdateProfileMessage = 'Профиль был обновлен.';
$strUpdateQuery = 'Дополнить запрос';
$strUpdComTab = 'Пожалуйста, посмотрите как обновить Column_comments Таблицу в документации';
$strUpgrade = 'Вы должны обновить %s до версии %s или выше.';
$strUsage = 'Использование';
$strUseBackquotes = 'Обратные кавычки в названиях таблиц и полей';
$strUsedPhpExtensions = 'Использованы расширения PHP';
$strUseHostTable = 'Использовать таблицу хостов';
$strUser = 'Пользователь';
$strUserAlreadyExists = 'Пользователь %s уже существует!';
$strUserEmpty = 'Пустое имя пользователя!';
$strUserName = 'Имя пользователя';
$strUserNotFound = 'Выделенный пользователь не был найден в таблице привилегий.';
$strUserOverview = 'Просмотр пользователей';
$strUsersDeleted = 'Выбранные пользователи были успешно удалены.';
$strUsersHavingAccessToDb = 'Пользователи с правами доступа к &quot;%s&quot;';
$strUseTables = 'Использовать таблицы';
$strUseTextField = 'Использовать текстовое поле';
$strUseThisValue = 'Использовать это значение';

$strValidateSQL = 'Проверить SQL';
$strValidatorError = 'Проверка SQL не может быть инициализирована. Проверьте, установлены ли необходимые модули расширений для PHP, описанные в %sдокументации%s.';
$strValue = 'Значение';
$strVar = 'Переменная';
$strViewDump = 'Просмотреть дамп таблицы';
$strViewDumpDatabases = 'Просмотреть дамп (схему) БД';
$strViewDumpDB = 'Просмотреть дамп БД';

$strWebServerUploadDirectory = 'директория, куда помещаются закачанные файлы от web-сервера';
$strWebServerUploadDirectoryError = 'директория, которую Вы установили как "upload" не может быть открыта';
$strWelcome = 'Добро пожаловать в %s';
$strWestEuropean = 'Западно-Европейский';
$strWildcard = 'шаблон';
$strWindowNotFound = 'Целевое окно браузера не может быть обновлено. Возможно, вы закрыли родительское окно или ваш браузер блокирует межоконные обновления из-за настроек безопасности';
$strWithChecked = 'С отмеченными:';
$strWrongUser = 'Ошибочный логин/пароль. В доступе отказано.';

$strXML = 'XML';
$strXMLOptions = 'Параметры XML';

$strYes = 'Да';

$strZeroRemovesTheLimit = 'Замечание: Установка этих параметров в 0 (ноль) снимает ограничения.';
$strZip = 'архивировать в zip';

// To translate:
$strAllowInterrupt = 'Allow interrupt of import in case script detects it is close to time limit. This might be good way to import large files, however it can break transactions.';  //to translate

$strBinaryLog = 'Binary log';  //to translate
$strBinLogName = 'Log name';  //to translate
$strBinLogOriginalPosition = 'Original position';  //to translate
$strBinLogPosition = 'Position';  //to translate
$strBinLogServerId = 'Server ID';  //to translate
$strBrowseForeignValues = 'Browse foreign values';  //to translate
$strBufferPool = 'Buffer Pool';  //to translate
$strBufferPoolActivity = 'Buffer Pool Activity';  //to translate
$strBufferPoolUsage = 'Buffer Pool Usage';  //to translate
$strBufferReadMisses = 'Read misses';  //to translate
$strBufferReadMissesInPercent = 'Read misses in %';  //to translate
$strBufferWriteWaits = 'Write waits';  //to translate
$strBufferWriteWaitsInPercent = 'Write waits in %';  //to translate
$strBusyPages = 'Busy pages';  //to translate

$strCanNotLoadExportPlugins = 'Could not load export plugins, please check your installation!';  //to translate
$strCanNotLoadImportPlugins = 'Could not load import plugins, please check your installation!';  //to translate

$strDefaultEngine = '%s is the default storage engine on this MySQL server.';  //to translate

$strEngineAvailable = '%s is available on this MySQL server.';  //to translate
$strEngineDisabled = '%s has been disabled for this MySQL server.';  //to translate
$strEngineUnsupported = 'This MySQL server does not support the %s storage engine.';  //to translate
$strEscapeWildcards = 'Wildcards _ and % should be escaped with a \ to use them literally';  //to translate
$strExportMustBeFile = 'Selected export type has to be saved in file!';  //to translate

$strFileNameTemplateDescription = 'This value is interpreted using %1$sstrftime%2$s, so you can use time formatting strings. Additionally the following transformations will happen: %3$s. Other text will be kept as is.';  //to translate
$strFreePages = 'Free pages';  //to translate

$strIndexWarningPrimary = 'PRIMARY and INDEX keys should not both be set for column `%s`';  //to translate
$strIndexWarningUnique = 'UNIQUE and INDEX keys should not both be set for column `%s`';  //to translate
$strInnoDBAutoextendIncrement = 'Autoextend increment';  //to translate
$strInnoDBAutoextendIncrementDesc = ' The increment size for extending the size of an autoextending tablespace when it becomes full.';  //to translate
$strInnoDBBufferPoolSize = 'Buffer pool size';  //to translate
$strInnoDBBufferPoolSizeDesc = 'The size of the memory buffer InnoDB uses to cache data and indexes of its tables.';  //to translate
$strInvalidAuthMethod = 'Invalid authentication method set in configuration:';  //to translate
$strInvalidLDIImport = 'This plugin does not support compressed imports!';  //to translate
$strInvalidServerHostname = 'Invalid hostname for server %1$s. Please review your configuration.';  //to translate
$strInvalidServerIndex = 'Invalid server index: "%s"';  //to translate

$strLatchedPages = 'Latched pages';  //to translate
$strLatexLabel = 'Label key';  //to translate
$strLDILocal = 'Use LOCAL keyword';  //to translate
$strLongOperation = 'This operation could be long. Proceed anyway?';  //to translate

$strMaxConnects = 'max. concurrent connections';  //to translate
$strMbExtensionMissing = 'The mbstring PHP extension was not found and you seem to be using multibyte charset. Without mbstring extension phpMyAdmin is unable to split strings correctly and it may result in unexpected results.';  //to translate
$strMbOverloadWarning = 'You have enabled mbstring.func_overload in your PHP configuration. This option is incompatible with phpMyAdmin and might cause breaking of some data!';  //to translate
$strMyISAMDataPointerSize = 'Data pointer size';  //to translate
$strMyISAMDataPointerSizeDesc = 'The default pointer size in bytes, to be used by CREATE TABLE for MyISAM tables when no MAX_ROWS option is specified.';  //to translate
$strMyISAMMaxExtraSortFileSize = 'Maximum size for temporary files on index creation';  //to translate
$strMyISAMMaxExtraSortFileSizeDesc = 'If the temporary file used for fast MyISAM index creation would be larger than using the key cache by the amount specified here, prefer the key cache method.';  //to translate
$strMyISAMMaxSortFileSize = 'Maximum size for temporary sort files';  //to translate
$strMyISAMMaxSortFileSizeDesc = 'The maximum size of the temporary file MySQL is allowed to use while re-creating a MyISAM index (during REPAIR TABLE, ALTER TABLE, or LOAD DATA INFILE).';  //to translate
$strMyISAMRecoverOptions = 'Automatic recovery mode';  //to translate
$strMyISAMRecoverOptionsDesc = 'The mode for automatic recovery of crashed MyISAM tables, as set via the --myisam-recover server startup option.';  //to translate
$strMyISAMRepairThreads = 'Repair threads';  //to translate
$strMyISAMRepairThreadsDesc = 'If this value is greater than 1, MyISAM table indexes are created in parallel (each index in its own thread) during the Repair by sorting process.';  //to translate
$strMyISAMSortBufferSize = 'Sort buffer size';  //to translate
$strMyISAMSortBufferSizeDesc = 'The buffer that is allocated when sorting MyISAM indexes during a REPAIR TABLE or when creating indexes with CREATE INDEX or ALTER TABLE.';  //to translate

$strNoActivity = 'No activity since %s seconds or more, please login again';  //to translate
$strNoDetailsForEngine = 'There is no detailed status information available for this storage engine.';  //to translate
$strNoThemeSupport = 'No themes support, please check your configuration and/or your themes in directory %s.';  //to translate

$strOpenDocumentSpreadsheet = 'Open Document Spreadsheet';  //to translate
$strOpenDocumentSpreadsheetOptions = 'Open Document Spreadsheet options';  //to translate

$strPagesToBeFlushed = 'Pages to be flushed';  //to translate
$strPasswordHashing = 'Password Hashing';  //to translate
$strPDFReportTitle = 'Report title';  //to translate
$strPrivDescAllPrivileges = 'Includes all privileges except GRANT.';  //to translate
$strPrivDescAlterRoutine = 'Allows altering and dropping stored routines.';  //to translate
$strPrivDescCreateRoutine = 'Allows creating stored routines.';  //to translate
$strPrivDescCreateUser = 'Allows creating, dropping and renaming user accounts.';  //to translate
$strPrivDescCreateView = 'Allows creating new views.';  //to translate
$strPrivDescExecute5 = 'Allows executing stored routines.';  //to translate
$strPrivDescMaxUserConnections = 'Limits the number of simultaneous connections the user may have.';  //to translate
$strPrivDescShowView = 'Allows performing SHOW CREATE VIEW queries.';  //to translate

$strReadRequests = 'Read requests';  //to translate

$strSelectBinaryLog = 'Select binary log to view';  //to translate
$strShowingBookmark = 'Showing bookmark';  //to translate
$strShowStatusBinlog_cache_disk_useDescr = 'The number of transactions that used the temporary binary log cache but that exceeded the value of binlog_cache_size and used a temporary file to store statements from the transaction.';  //to translate
$strShowStatusBinlog_cache_useDescr = 'The number of transactions that used the temporary binary log cache.';  //to translate
$strShowStatusHandler_discoverDescr = 'The MySQL server can ask the NDB Cluster storage engine if it knows about a table with a given name. This is called discovery. Handler_discover indicates the number of time tables have been discovered.';  //to translate
$strShowStatusInnodb_buffer_pool_pages_dataDescr = 'The number of pages containing data (dirty or clean).';  //to translate
$strShowStatusInnodb_buffer_pool_pages_dirtyDescr = 'The number of pages currently dirty.';  //to translate
$strShowStatusInnodb_buffer_pool_pages_flushedDescr = 'The number of buffer pool pages that have been requested to be flushed.';  //to translate
$strShowStatusInnodb_buffer_pool_pages_freeDescr = 'The number of free pages.';  //to translate
$strShowStatusInnodb_buffer_pool_pages_latchedDescr = 'The number of latched pages in InnoDB buffer pool. These are pages currently being read or written or that can\'t be flushed or removed for some other reason.';  //to translate
$strShowStatusInnodb_buffer_pool_pages_miscDescr = 'The number of pages busy because they have been allocated for administrative overhead such as row locks or the adaptive hash index. This value can also be calculated as Innodb_buffer_pool_pages_total - Innodb_buffer_pool_pages_free - Innodb_buffer_pool_pages_data.';  //to translate
$strShowStatusInnodb_buffer_pool_pages_totalDescr = 'Total size of buffer pool, in pages.';  //to translate
$strShowStatusInnodb_buffer_pool_read_ahead_rndDescr = 'The number of "random" read-aheads InnoDB initiated. This happens when a query is to scan a large portion of a table but in random order.';  //to translate
$strShowStatusInnodb_buffer_pool_read_ahead_seqDescr = 'The number of sequential read-aheads InnoDB initiated. This happens when InnoDB does a sequential full table scan.';  //to translate
$strShowStatusInnodb_buffer_pool_read_requestsDescr = 'The number of logical read requests InnoDB has done.';  //to translate
$strShowStatusInnodb_buffer_pool_readsDescr = 'The number of logical reads that InnoDB could not satisfy from buffer pool and had to do a single-page read.';  //to translate
$strShowStatusInnodb_buffer_pool_wait_freeDescr = 'Normally, writes to the InnoDB buffer pool happen in the background. However, if it\'s necessary to read or create a page and no clean pages are available, it\'s necessary to wait for pages to be flushed first. This counter counts instances of these waits. If the buffer pool size was set properly, this value should be small.';  //to translate
$strShowStatusInnodb_buffer_pool_write_requestsDescr = 'The number writes done to the InnoDB buffer pool.';  //to translate
$strShowStatusInnodb_data_fsyncsDescr = 'The number of fsync() operations so far.';  //to translate
$strShowStatusInnodb_data_pending_fsyncsDescr = 'The current number of pending fsync() operations.';  //to translate
$strShowStatusInnodb_data_pending_readsDescr = 'The current number of pending reads.';  //to translate
$strShowStatusInnodb_data_pending_writesDescr = 'The current number of pending writes.';  //to translate
$strShowStatusInnodb_data_readDescr = 'The amount of data read so far, in bytes.';  //to translate
$strShowStatusInnodb_data_readsDescr = 'The total number of data reads.';  //to translate
$strShowStatusInnodb_data_writesDescr = 'The total number of data writes.';  //to translate
$strShowStatusInnodb_data_writtenDescr = 'The amount of data written so far, in bytes.';  //to translate
$strShowStatusInnodb_dblwr_pages_writtenDescr = 'The number of doublewrite writes that have been performed and the number of pages that have been written for this purpose.';  //to translate
$strShowStatusInnodb_dblwr_writesDescr = 'The number of doublewrite writes that have been performed and the number of pages that have been written for this purpose.';  //to translate
$strShowStatusInnodb_log_waitsDescr = 'The number of waits we had because log buffer was too small and we had to wait for it to be flushed before continuing.';  //to translate
$strShowStatusInnodb_log_write_requestsDescr = 'The number of log write requests.';  //to translate
$strShowStatusInnodb_log_writesDescr = 'The number of physical writes to the log file.';  //to translate
$strShowStatusInnodb_os_log_fsyncsDescr = 'The number of fsyncs writes done to the log file.';  //to translate
$strShowStatusInnodb_os_log_pending_fsyncsDescr = 'The number of pending log file fsyncs.';  //to translate
$strShowStatusInnodb_os_log_pending_writesDescr = 'Pending log file writes.';  //to translate
$strShowStatusInnodb_os_log_writtenDescr = 'The number of bytes written to the log file.';  //to translate
$strShowStatusInnodb_page_sizeDescr = 'The compiled-in InnoDB page size (default 16KB). Many values are counted in pages; the page size allows them to be easily converted to bytes.';  //to translate
$strShowStatusInnodb_pages_createdDescr = 'The number of pages created.';  //to translate
$strShowStatusInnodb_pages_readDescr = 'The number of pages read.';  //to translate
$strShowStatusInnodb_pages_writtenDescr = 'The number of pages written.';  //to translate
$strShowStatusInnodb_row_lock_current_waitsDescr = 'The number of row locks currently being waited for.';  //to translate
$strShowStatusInnodb_row_lock_time_avgDescr = 'The average time to acquire a row lock, in milliseconds.';  //to translate
$strShowStatusInnodb_row_lock_time_maxDescr = 'The maximum time to acquire a row lock, in milliseconds.';  //to translate
$strShowStatusInnodb_row_lock_timeDescr = 'The total time spent in acquiring row locks, in milliseconds.';  //to translate
$strShowStatusInnodb_row_lock_waitsDescr = 'The number of times a row lock had to be waited for.';  //to translate
$strShowStatusInnodb_rows_deletedDescr = 'The number of rows deleted from InnoDB tables.';  //to translate
$strShowStatusInnodb_rows_insertedDescr = 'The number of rows inserted in InnoDB tables.';  //to translate
$strShowStatusInnodb_rows_readDescr = 'The number of rows read from InnoDB tables.';  //to translate
$strShowStatusInnodb_rows_updatedDescr = 'The number of rows updated in InnoDB tables.';  //to translate
$strShowStatusLast_query_costDescr = 'The total cost of the last compiled query as computed by the query optimizer. Useful for comparing the cost of different query plans for the same query. The default value of 0 means that no query has been compiled yet.';  //to translate
$strSkipQueries = 'Number of records(queries) to skip from start';  //to translate
$strSocketProblem = '(or the local MySQL server\'s socket is not correctly configured)';  //to translate
$strSQLCompatibility = 'SQL compatibility mode';  //to translate
$strStatisticsOverrun = 'On a busy server, the byte counters may overrun, so those statistics as reported by the MySQL server may be incorrect.';  //to translate
$strStorageEngine = 'Storage Engine';  //to translate
$strStrucNativeExcelOptions = 'Native Excel export options';  //to translate

$strThemeNoValidImgPath = 'No valid image path for theme %s found!';  //to translate
$strThemePathNotFound = 'Theme path not found for theme %s!';  //to translate
$strTimeoutInfo = 'Previous import timed out, after resubmitting will continue from position %d.';  //to translate
$strTimeoutNothingParsed = 'However on last run no data has been parsed, this usually means phpMyAdmin won\'t be able to finish this import unless you increase php time limits.';  //to translate
$strTimeoutPassed = 'Script timeout passed, if you want to finish import, please resubmit same file and import will resume.';  //to translate
$strTransactionCoordinator = 'Transaction coordinator';  //to translate
$strTransformation_application_octetstream__hex = 'Displays hexadecimal representation of data. Optional first parameter specifies how often space will be added (defaults to 2 nibbles).';  //to translate
$strTransformation_text_plain__sql = 'Formats text as SQL query with syntax highlighting.';  //to translate

$strUnsupportedCompressionDetected = 'You attempted to load file with unsupported compression (%s). Either support for it is not implemented or disabled by your configuration.';  //to translate
$strUploadLimit = 'You probably tried to upload too large file. Please refer to %sdocumentation%s for ways to workaround this limit.';  //to translate
$strUploadsNotAllowed = 'File uploads are not allowed on this server.';  //to translate
$strUseTabKey = 'Use TAB key to move from value to value, or CTRL+arrows to move anywhere';  //to translate
$strVersionInformation = 'Version information';  //to translate

$strView = 'View';  //to translate
$strViewHasBeenDropped = 'View %s has been dropped';  //to translate
$strViewMaxExactCount = 'This view has more than %s rows. Please refer to %sdocumentation%s.';  //to translate

$strWriteRequests = 'Write requests';  //to translate

$strPmaWiki = 'phpMyAdmin wiki';  //to translate
$strTransformation_text_plain__dateformat = 'Displays a TIME, TIMESTAMP, DATETIME or numeric unix timestamp field as formatted date. The first option is the offset (in hours) which will be added to the timestamp (Default: 0). Use second option to specify a different date/time format string. Third option determines whether you want to see local date or UTC one (use "local" or "utc" strings) for that. According to that, date format has different value - for "local" see the documentation for PHP\'s strftime() function and for "utc" it is done using gmdate() function.';  //to translate
$strDocSQL = 'DocSQL';  //to translate
$strDocSQLOptions = 'DocSQL options';  //to translate
$strTableName = 'Table name';  //to translate
$strTableIsEmpty = 'Table seems to be empty!';  //to translate
$strDbIsEmpty = 'Database seems to be empty!';  //to translate
$strShowingPhp = 'Showing as PHP code';  //to translate
$strShowingSQL = 'Showing SQL query';  //to translate
$strDesigner = 'Designer';  //to translate
$strNumberOfTables = 'Number of tables';  //to translate
$strCreateTable  = 'Create table';  //to translate
$strCreateRelation = 'Create relation';  //to translate
$strSavePosition = 'Save position';  //to translate
$strSelectForeignKey = 'Select Foreign Key';  //to translate
$strHide         = 'Hide';  //to translate
$strShowHideLeftMenu = 'Show/Hide left menu';  //to translate
$strReload = 'Reload';  //to translate
$strSmallBigAll = 'Small/Big All';  //to translate
$strImportExportCoords = 'Import/Export coordinates for PDF schema';  //to translate
$strMoveMenu = 'Move Menu';  //to translate
$strAngularLinks = 'Angular links';  //to translate
$strDirectLinks = 'Direct links';  //to translate
$strHideShowAll = 'Hide/Show all';  //to translate
$strHideShowNoRelation = 'Hide/Show Tables with no relation';  //to translate
$strInternalRelationAdded = 'Internal relation added';  //to translate
$strInnoDBRelationAdded = 'InnoDB relation added';  //to translate
$strRelationDeleted = 'Relation deleted';  //to translate
$strToSelectRelation = 'To select relation, click :';  //to translate
$strExportImportToScale = 'Export/Import to scale';  //to translate
$strRecommended = 'recommended';  //to translate
$strToFromPage = 'to/from page';  //to translate
$strSelectReferencedKey = 'Select referenced key';  //to translate
$strPleaseSelectPrimaryOrUniqueKey = 'Please select the primary key or a unique key';  //to translate
$strForeignKeyError = 'Error creating foreign key (check data types)';  //to translate
$strHelp = 'Help';  //to translate
$strCancel = 'Cancel';  //to translate
$strDeleteRelation = 'Delete relation';  //to translate
$strKnownExternalBug = 'The %s functionality is affected by a known bug, see %s';  //to translate
$strStructureForView = 'Structure for view';  //to translate
$strStandInStructureForView = 'Stand-in structure for view';  //to translate
$strToggleSmallBig = 'Toggle small/big';  //to translate
$strIEUnsupported = 'Internet Explorer does not support this function.';  //to translate
$strErrorRelationAdded = 'Error: Relation not added.';  //to translate
$strErrorRelationExists = 'Error: relation already exists.';  //to translate
$strErrorSaveTable = 'Error saving coordinates for Designer.';  //to translate
$strSnapToGrid = 'Snap to grid';  //to translate
$strDesignerHelpDisplayField = 'The display field is shown in pink. To set/unset a field as the display field, click the "Choose field to display" icon, then click on the appropriate field name.';  //to translate
?>
